.nafo_pts: this value is to be used in geom_point to define point size (it is 3 pt converted to mm)
.nafo_lwd: this value is to be used in geom_line to define line width (it is 0.75 pt converted to mm)
.nafo_stroke: this value is to be used in geom_point to define stroke width (it is 0.75 pt converted to 1/96 inches)
.nafo_height: this value is to be used to define plot height in inches (it is 6.4 cm converted to inches)
.nafo_width: this value is to be used to define plot width in inches (it is 11.5 cm converted to inches)
.nafo_asp: this value is to be used to define the aspect ratio of a plot
.nafo_cols: vector of colours to use in plots
.nafo_pts
.nafo_lwd
.nafo_stroke
.nafo_height
.nafo_width
.nafo_asp
.nafo_cols